#' @name pList
#' @title List of plots for ggedit examples
#' @description List of ggplot objects for examples in ggedit.
#'
#' @docType data
#'
#' @usage pList
#'
#' @format An object of class \code{"list"}
#'
#' @keywords datasets
#'
#' @details
#' list includes a geom_point, geom_point+facet_wrap, geom_boxplot+facet_wrap,
#' geom_point+geom_line, geom_point+geom_smooth, geom_point+geom_line+facet_wrap,
#' geom_point+geom_line+facet_grid
#'
"pList"
